@@ -50,6 +50,7 @@ class HTTPClient(object):
 
     def __init__(self, endpoint, **kwargs):
         self.endpoint = endpoint
+        self.auth_url = kwargs.get('auth_url')
         self.auth_token = kwargs.get('token')
         self.username = kwargs.get('username')
         self.password = kwargs.get('password')
@@ -131,6 +132,8 @@ class HTTPClient(object):
         kwargs['headers'].setdefault('User-Agent', USER_AGENT)
         if self.auth_token:
             kwargs['headers'].setdefault('X-Auth-Token', self.auth_token)
+        if self.auth_url:
+            kwargs['headers'].setdefault('X-Auth-Url', self.auth_url)
         if self.username:
             kwargs['headers'].setdefault('X-Auth-User', self.username)
         if self.password:
@@ -163,9 +166,7 @@ class HTTPClient(object):
             self.log_http_response(resp)
 
         if 400 <= resp.status < 600:
-            if resp.status != 404:
-                LOG.warn("Request returned failure status %s" % resp.status)
-            raise exc.from_response(resp)
+            raise exc.from_response(resp, body_iter)
         elif resp.status in (301, 302, 305):
             # Redirected. Reissue the request to the new location.
             location = resp.getheader('location', None)
@@ -180,7 +181,7 @@ class HTTPClient(object):
                 raise exc.InvalidEndpoint(message=message)
             return self._http_request(location, method, **kwargs)
         elif resp.status == 300:
-            raise exc.from_response(resp)
+            raise exc.from_response(resp, body_iter)
 
         return resp, body_iter
 
